@@ -22,6 +22,7 @@
 #define _m_ctype_h
 
 #include <my_attribute.h>
+#include <m_string.h>
 
 enum loglevel {
    ERROR_LEVEL=       0,
@@ -79,6 +80,7 @@ typedef const struct my_collation_handler_st MY_COLLATION_HANDLER;
 typedef const struct unicase_info_st MY_UNICASE_INFO;
 typedef const struct uni_ctype_st MY_UNI_CTYPE;
 typedef const struct my_uni_idx_st MY_UNI_IDX;
+typedef uint16 decimal_digits_t;
 
 typedef struct unicase_info_char_st
 {
@@ -343,8 +345,7 @@ enum my_lex_states
   MY_LEX_IDENT_OR_KEYWORD,
   MY_LEX_IDENT_OR_HEX, MY_LEX_IDENT_OR_BIN, MY_LEX_IDENT_OR_NCHAR,
   MY_LEX_STRING_OR_DELIMITER, MY_LEX_MINUS_OR_COMMENT, MY_LEX_PLACEHOLDER,
-  MY_LEX_COMMA,
-  MY_LEX_IDENT_OR_QUALIFIED_SPECIAL_FUNC
+  MY_LEX_COMMA
 };
 
 struct charset_info_st;
@@ -453,6 +454,12 @@ struct my_collation_handler_st
   void (*hash_sort)(CHARSET_INFO *cs, const uchar *key, size_t len,
 		    ulong *nr1, ulong *nr2); 
   my_bool (*propagate)(CHARSET_INFO *cs, const uchar *str, size_t len);
+  /*
+    Make minimum and maximum strings for the collation.
+    Put not more than "nchars" characters.
+  */
+  size_t (*min_str)(CHARSET_INFO *cs, uchar *dst, size_t dstlen, size_t nchars);
+  size_t (*max_str)(CHARSET_INFO *cs, uchar *dst, size_t dstlen, size_t nchars);
 };
 
 extern MY_COLLATION_HANDLER my_collation_8bit_bin_handler;
@@ -646,8 +653,8 @@ struct charset_info_st
   uint      primary_number;
   uint      binary_number;
   uint      state;
-  const char *csname;
-  const char *name;
+  LEX_CSTRING cs_name;
+  LEX_CSTRING coll_name;
   const char *comment;
   const char *tailoring;
   const uchar *m_ctype;
@@ -665,8 +672,23 @@ struct charset_info_st
   uchar     casedn_multiply;
   uint      mbminlen;
   uint      mbmaxlen;
+  /*
+    min_sort_char and max_sort_char represent the minimum
+    and the maximum character in the collation respectively.
+
+    For Unicode collations, these numbers are Unicode code points.
+    For non-Unicode collations these numbers are native character codes.
+    For example, in all 8bit collations these numbers are
+    in the range 0x00..0xFF.
+
+    min_sort_char and max_sort_char normally should not be used directly.
+    They are used internally in the following virtual functions:
+    - MY_COLLATION_HANDLER::like_range()
+    - MY_COLLATION_HANDLER::min_str()
+    - MY_COLLATION_HANDLER::max_str()
+  */
   my_wc_t   min_sort_char;
-  my_wc_t   max_sort_char; /* For LIKE optimization */
+  my_wc_t   max_sort_char;
   uchar     pad_char;
   my_bool   escape_with_backslash_is_dangerous;
   uchar     levels_for_order;
@@ -865,6 +887,12 @@ struct charset_info_st
     return (coll->strnncollsp)(this, (uchar *) a, alen, (uchar *) b, blen);
   }
 
+  int strnncollsp(const LEX_CSTRING &a, const LEX_CSTRING &b) const
+  {
+    return (coll->strnncollsp)(this, (uchar *) a.str, a.length,
+                                     (uchar *) b.str, b.length);
+  }
+
   size_t strnxfrm(char *dst, size_t dstlen, uint nweights,
                   const char *src, size_t srclen, uint flags) const
   {
@@ -928,6 +956,16 @@ struct charset_info_st
     return (coll->propagate)(this, str, len);
   }
 
+  size_t min_str(uchar *dst, size_t dstlen, size_t nchars) const
+  {
+    return (coll->min_str)(this, dst, dstlen, nchars);
+  }
+
+  size_t max_str(uchar *dst, size_t dstlen, size_t nchars) const
+  {
+    return (coll->max_str)(this, dst, dstlen, nchars);
+  }
+
 #endif /* __cplusplus */
 };
 
@@ -1186,7 +1224,7 @@ extern struct charset_info_st my_charset_big5_bin;
 extern struct charset_info_st my_charset_big5_chinese_ci;
 extern struct charset_info_st my_charset_big5_nopad_bin;
 extern struct charset_info_st my_charset_big5_chinese_nopad_ci;
-extern struct charset_info_st my_charset_cp1250_czech_ci;
+extern struct charset_info_st my_charset_cp1250_czech_cs;
 extern struct charset_info_st my_charset_cp932_bin;
 extern struct charset_info_st my_charset_cp932_japanese_ci;
 extern struct charset_info_st my_charset_cp932_nopad_bin;
@@ -1210,7 +1248,7 @@ extern struct charset_info_st my_charset_gbk_chinese_nopad_ci;
 extern struct charset_info_st my_charset_latin1_bin;
 extern struct charset_info_st my_charset_latin1_nopad_bin;
 extern struct charset_info_st my_charset_latin1_german2_ci;
-extern struct charset_info_st my_charset_latin2_czech_ci;
+extern struct charset_info_st my_charset_latin2_czech_cs;
 extern struct charset_info_st my_charset_sjis_bin;
 extern struct charset_info_st my_charset_sjis_japanese_ci;
 extern struct charset_info_st my_charset_sjis_nopad_bin;
@@ -1260,7 +1298,7 @@ extern struct charset_info_st my_charset_utf8mb4_general_nopad_ci;
 extern struct charset_info_st my_charset_utf8mb4_unicode_ci;
 extern struct charset_info_st my_charset_utf8mb4_unicode_nopad_ci;
 
-#define MY_UTF8MB3                 "utf8"
+#define MY_UTF8MB3                 "utf8mb3"
 #define MY_UTF8MB4                 "utf8mb4"
 
 my_bool my_cs_have_contractions(CHARSET_INFO *cs);
@@ -1673,6 +1711,9 @@ my_well_formed_length(CHARSET_INFO *cs, const char *b, const char *e,
 #include "t_ctype.h"
 #endif
 
+int my_wc_mb_utf8mb4_bmp_only(CHARSET_INFO *cs, my_wc_t wc, uchar *r,
+                              uchar *e);
+
 #ifdef	__cplusplus
 }
 #endif
