@@ -72,7 +72,6 @@
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_MALLOC_H 1
 #define HAVE_SYS_MMAN_H 1
-/* #undef HAVE_SYS_MNTENT_H */
 /* #undef HAVE_SYS_NDIR_H */
 /* #undef HAVE_SYS_PTE_H */
 /* #undef HAVE_SYS_PTEM_H */
@@ -109,6 +108,7 @@
 /* Libraries */
 #define HAVE_LIBWRAP 1
 /* #undef HAVE_SYSTEMD */
+/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -141,7 +141,7 @@
 #define HAVE_FDATASYNC 1
 #define HAVE_DECL_FDATASYNC 1
 #define HAVE_FEDISABLEEXCEPT 1
-#define HAVE_FESETROUND 1
+/* #undef HAVE_FESETROUND */
 #define HAVE_FP_EXCEPT 1
 #define HAVE_FSEEKO 1
 #define HAVE_FSYNC 1
@@ -168,7 +168,6 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-/* #undef HAVE_MEMALIGN */
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
@@ -195,7 +194,6 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
-#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -204,9 +202,9 @@
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
 /* #undef HAVE_PTHREAD_YIELD_ZERO_ARG */
-#define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
+/* #undef PTHREAD_ONCE_INITIALIZER */
 #define HAVE_PUTENV 1
-#define HAVE_READDIR_R 1
+/* #undef HAVE_READDIR_R */
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -233,6 +231,7 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
+/* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
@@ -278,10 +277,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define HAVE_LONG 1
@@ -296,7 +295,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -334,7 +333,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -395,8 +394,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "powerpc"
-#define DEFAULT_MACHINE "powerpc"
+#define MACHINE_TYPE "alpha"
+#define DEFAULT_MACHINE "alpha-64bit"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -431,7 +430,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -499,7 +498,6 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
-#define HAVE_des 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -531,17 +529,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 29
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 16
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.29"
+#define PACKAGE_STRING "MySQL Server 10.6.16"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.29"
-#define VERSION "10.5.29"
+#define PACKAGE_VERSION "10.6.16"
+#define VERSION "10.6.16"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -564,4 +562,4 @@
 
 #endif
 
-#define HAVE_VFORK 1
+/* #undef HAVE_VFORK */
